# Usage

## copying

-   copy file to pasteboard as UTI: `tacky copy -i public.text <name of file>`
-   copy stdin to pasteboard as UTI: `tacky copy -i public.text -`

## pasting

-   paste from pasteboard to stdout as UTI: `tacky paste -u public.text`
-   list available UTI's from pasteboard to stdout: `tacky paste --list`
